| url_destination | R Documentation |
If a URL is redirected, query the new location via curlGetHeaders(),
otherwise return the original URL.
url_destination(x, force = FALSE)
x |
A character vector of URLs. |
force |
By default, the query is cached in the current R session. To
bypass the cache, use |
The final destination(s). If the URL returns a status code greater than or equal to 400, it will throw an error.
u = "https://cran.r-project.org/package=xfun"
url_destination(u) # redirected to canonical URL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.