is_abs_path: Test if paths are relative or absolute
Description
On Unix, check if the paths start with / or ~ (if they do, they
are absolute paths). On Windows, check if the paths start with a drive letter
(e.g., C:), a (back)slash (e.g., /foo), a UNC prefix (e.g.,
\\host\share), or ~.