| post_release | R Documentation |
After a CRAN release is accepted, commit and tag the release, bump the package version to the next patch dev version, prepend a new header to ‘NEWS.md’, push to the remote repository, and create a GitHub release with the news items of this version.
post_release()
The version number X.Y or X.Y.0 is extracted from the Version field in
‘DESCRIPTION’. For example, if the current version is 0.58 (or
0.58.0), the repo will be tagged as v0.58 (or v0.58.0). The patch
version is then bumped to 0.58.1, and a new header for the next minor
version 0.59 (or 0.59.0) is prepended to ‘NEWS.md’.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.