post_release: Perform post-CRAN-release routine tasks

View source: R/github.R

post_releaseR Documentation

Perform post-CRAN-release routine tasks

Description

After a CRAN release is accepted, commit and tag the release, bump the package version to the next patch dev version, prepend a new header to ‘NEWS.md’, push to the remote repository, and create a GitHub release with the news items of this version.

Usage

post_release()

Details

The version number ‘⁠X.Y⁠’ is extracted from the ‘⁠Version⁠’ field in ‘DESCRIPTION’. For example, if the current version is ‘⁠0.58⁠’, the repo will be tagged as ‘⁠v0.58⁠’. The patch version is then bumped to ‘⁠0.58.1⁠’, and a new header is prepended to ‘NEWS.md’.


xfun documentation built on June 19, 2026, 9:06 a.m.