Learn R Programming

xfun (version 0.61)

post_release: Perform post-CRAN-release routine tasks

Description

After a CRAN release is accepted, commit and tag the release, bump the package version to the next patch dev version, prepend a new header to NEWS.md, push to the remote repository, and create a GitHub release with the news items of this version.

Usage

post_release()

Arguments

Details

The repo will be tagged with the version number extracted from the Version field in DESCRIPTION. Then .1 is appended to Version in DESCRIPTION as the next patch version, and a new header for the next release version (which is from bumping the last digit of the current version) is prepended to NEWS.md. For example, if the current version is 1.2.3 (or 1.2), the next patch version will be 1.2.3.1 (or 1.2.1) and the next release version will be 1.2.4 (or 1.3).